@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -13,9 +13,7 @@ ItemContextTest::ItemContextTest(QObject *parent)
 {
 }
 
-ItemContextTest::~ItemContextTest()
-{
-}
+ItemContextTest::~ItemContextTest() = default;
 
 void ItemContextTest::shouldHaveDefaultValue()
 {
